"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const cli_utils_1 = require("@ionic/cli-utils");
const build_1 = require("./build");
const generate_1 = require("./generate");
const serve_1 = require("./serve");
exports.name = '@ionic/cli-plugin-ionic-angular';
exports.version = '1.0.0-beta0-alpha.9a8116f6';
function getIonicAngularVersion(env) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const ionicAngularPackageJson = yield cli_utils_1.readPackageJsonFile(path.resolve(env.project.directory, 'node_modules', 'ionic-angular', 'package.json'));
            return ionicAngularPackageJson.version;
        }
        catch (e) {
            env.log.error('Error with ionic-angular package.json file:', e);
        }
    });
}
;
function getAppScriptsVersion(env) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const appScriptsPackageJson = yield cli_utils_1.readPackageJsonFile(path.resolve(env.project.directory, 'node_modules', '@ionic', 'app-scripts', 'package.json'));
            return appScriptsPackageJson.version;
        }
        catch (e) {
            env.log.error('Error with @ionic/app-scripts package.json file:', e);
        }
    });
}
;
function registerHooks(hooks) {
    hooks.register(exports.name, 'command:docs', ({ env }) => __awaiter(this, void 0, void 0, function* () {
        const docsHomepage = 'https://ionicframework.com/docs';
        if (!env.project.directory) {
            return docsHomepage;
        }
        const ionicAngularVersion = yield getIonicAngularVersion(env);
        const url = `${docsHomepage}/${ionicAngularVersion ? ionicAngularVersion + '/' : ''}api`;
        return url;
    }));
    hooks.register(exports.name, 'command:generate', (args) => __awaiter(this, void 0, void 0, function* () {
        yield generate_1.generate(args);
    }));
    hooks.register(exports.name, 'command:info', ({ env }) => __awaiter(this, void 0, void 0, function* () {
        if (!env.project.directory) {
            return [];
        }
        const [ionicAngularVersion, appScriptsVersion] = yield Promise.all([getIonicAngularVersion(env), getAppScriptsVersion(env)]);
        return [
            { type: 'local-npm', name: 'Ionic Framework', version: ionicAngularVersion ? `ionic-angular ${ionicAngularVersion}` : 'not installed' },
            { type: 'local-npm', name: exports.name, version: exports.version },
            { type: 'local-npm', name: '@ionic/app-scripts', version: appScriptsVersion ? appScriptsVersion : 'not installed' },
        ];
    }));
    hooks.register(exports.name, 'command:serve', (args) => __awaiter(this, void 0, void 0, function* () {
        return serve_1.serve(args);
    }));
    hooks.register(exports.name, 'command:build', (args) => __awaiter(this, void 0, void 0, function* () {
        yield build_1.build(args);
    }));
}
exports.registerHooks = registerHooks;
